def func(text1, text2, number):
    return f"Hello  {text1} {text2}  {number} !!", number + 1


if __name__ == "__main__":
    import gradio as gr

    iface = gr.Interface(fn=func,
                         inputs=["text", "checkbox", gr.inputs.Slider(0, 100)],
                         outputs=["text", "number"],
                         title="emmmmmm",
                         # description=description,
                         # article=article,
                         examples=[["lalala", False, 100], ["emmm", True, 1], ["aaa", True, 101]]
                         )
    iface.launch(debug=True)



from sparrow.path import rel_to_abs
from sparrow import yaml_load
import os


def test_rel_to_abs():
    assert os.path.exists(rel_to_abs("test_path.py"))
    assert os.path.exists(rel_to_abs("../sparrow"))
    assert os.path.exists(rel_to_abs("../sparrow/__init__.py"))



from cmath import log
import pytest
from sparrow.performance import MeasureTime
from sparrow.log import SimpleLogger
from sparrow import rel_to_abs


# parametrize 参数化测试用例, 意义就是
# 我们只需要编写一个测试用例，然后用这个装饰器 实现不同的值的测试用例 被多次执行。
# 这个优势，暂时看起来就是能然不同的测试用例执行起来清晰一点。。。
@pytest.mark.parametrize("value", [1, 2, "1", "2"])
def test_print_func(value):
    print(value)


# fixture 夹具，用于初始化的参数的，暂时没明白为啥大家都这么夸这玩意儿.
# 有点懂了，依旧是，后面每次调用这个参数时，都会被重新初始化
# 又有点懂了，这玩意儿可以看成是类中的__init__(), 这样我们的测试用例就不用写在类里面了。
@pytest.fixture(params=["a", "b", "c"])
def a_array(request):
    inputs = [1, 2, 3]
    log1 = SimpleLogger("log1", log_dir=rel_to_abs("./log1"))
    log2 = SimpleLogger("log2", log_dir=rel_to_abs("./log2"))
    return (inputs, log1, log2, request.param)  # request.param会依次将params里面的值返回去


def test_print1(a_array):
    print(a_array)



import copy
import ml_collections


referenced_dict = {"inner_float": 3.14}
d = {
    "referenced_dict_1": referenced_dict,
    "referenced_dict_2": referenced_dict,
    "list_containing_dict": [{"key": "value"}],
}

# We can initialize on a dictionary
cfg = ml_collections.ConfigDict(d)

print(cfg)



from pathlib import Path
import inspect


def rel_to_abs(rel_path: str, parents=0):
    """Return absolute path relative to the called file"""
    currentframe = inspect.currentframe()
    f = currentframe.f_back
    if parents:
        for _ in range(parents):
            f = f.f_back
    current_path = Path(f.f_code.co_filename).parent
    return current_path / rel_path



from sparrow.log.core import Logger
from sparrow.ner import Extractor
from sparrow.log import SimpleLogger
from sparrow import rel_to_abs
import pytest


@pytest.fixture
def extractor():
    return Extractor()


@pytest.fixture
def logger():
    return SimpleLogger("extract-log", log_dir=rel_to_abs("log-ner"))


@pytest.mark.parametrize("text", ("我的手机号码是13120572919", "我的手机是+86-13120572919你还记得吗"))
def test_extractor(extractor: Extractor, logger: SimpleLogger, text: str):

    logger.debug(extractor.extract_cellphone(text))
    logger.debug(
        extractor.extract_email(
            "emmmm則我的email是beidongjiedeguang@gmail.com或者502245897@qq.com或者kunyuan@163.com"
        )
    )
    assert extractor.extract_email("emmmm則我的email是beidongjiedeguang@gmail.com或者") == [
        "beidongjiedeguang@gmail.com"
    ]

    assert extractor.extract_email("emmm怎麼說呢502245897@qq.com或者") == ["502245897@qq.com"]
